package com.chelvc.cloud.admin.controller;
import com.chelvc.cloud.vehicle.api.dto.OmsOrderDTO;
import com.chelvc.cloud.vehicle.api.dto.OmsOrderDetailDTO;
import com.chelvc.cloud.vehicle.api.param.OrderPagingParam;
import com.chelvc.cloud.vehicle.api.service.IOmsOrderService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;
import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * 订单接口
 *
 * @author liude
 * @Date 2023/11/29
 **/
@Validated
@RestController
@ResponseWrapping
public class OrderController {
    @DubboReference
    private IOmsOrderService orderService;

    /**
     * 查询订单分页
     *
     * @param param 查询参数
     * @return 订单分页信息
     */
    @GetMapping("/order/paging")
    public Pagination<OmsOrderDTO> getOrderPaging(@Valid OrderPagingParam param) {
        return this.orderService.getOmsOrderPaging(param);
    }


    /**
     * 查询订单详情
     *
     * @param id 查询参数
     * @return
     */
    @GetMapping("/order/{id}")
    public OmsOrderDetailDTO getOrderDetail(@PathVariable("id") @Min(value = 1, message = "主键不能小于1") Long id) {
        return this.orderService.detail(id);
    }

    /**
     *
     * 核验订单
     * @param orderId
     * @param merchantId
     * @return
     */
    @GetMapping("/order/verification/{orderId}/{merchantId}")
    public void orderVerification(@PathVariable("orderId") @NotNull(message = "订单错误") Long orderId,
                                  @PathVariable("merchantId") @NotNull(message = "订单错误") Long merchantId) {
        this.orderService.orderVerification(orderId, merchantId);
    }
}
